'use client';

import { useState, useEffect, Suspense } from 'react';
import { useSearchParams, useRouter } from 'next/navigation';
import Link from 'next/link';
import { EditableText } from '@/components/EditableText';
import { VoteOption, VoteOptionConfig } from '@/lib/survey';


export default function VotePage() {
  return (
    <Suspense fallback={<LoadingComponent />}>
      <VotePageContent />
    </Suspense>
  );
}

function LoadingComponent() {
  return <div>Lädt...</div>;
}

function VotePageContent() {
  const searchParams = useSearchParams();
  const router = useRouter();
  const token = searchParams.get('token');

  const [voteOptions, setVoteOptions] = useState<VoteOptionConfig[]>([]);
  const [selectedOption, setSelectedOption] = useState<VoteOption | null>(null);
  const [comment, setComment] = useState('');
  const [isLoading, setIsLoading] = useState(false);
  const [error, setError] = useState<string | null>(null);
  const [isSubmitted, setIsSubmitted] = useState(false);
  // Fetch vote options
  useEffect(() => {
    const fetchVoteOptions = async () => {
      try {
        const response = await fetch('/api/editable-text');
        if (response.ok) {
          const data = await response.json();
          if (data.texts && Array.isArray(data.texts)) {
            const voteOptionsEntry = data.texts.find((text: { id: string }) => text.id === 'vote-options');
            if (voteOptionsEntry && Array.isArray(voteOptionsEntry.content)) {
              setVoteOptions(voteOptionsEntry.content);
            }
          }
        }
      } catch (error) {
        console.error('Error fetching vote options:', error);
        // Use default options if fetch fails
        setVoteOptions([
          { id: 'yes', label: 'Ja, ich stimme zu' },
          { id: 'no', label: 'Nein, ich stimme nicht zu' },
          { id: 'abstain', label: 'Ich enthalte mich' }
        ]);
      }
    };

    fetchVoteOptions();
  }, []);

  // Redirect if no token is provided
  useEffect(() => {
    if (!token) {
      router.push('/');
    }
  }, [token, router]);

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();

    if (!selectedOption) {
      setError('Bitte wähle eine Option');
      return;
    }

    setIsLoading(true);
    setError(null);

    try {
      const response = await fetch('/api/submit-vote', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify({
          token,
          vote: selectedOption,
          comment: comment.trim() || undefined,
        }),
      });

      const data = await response.json();

      if (!response.ok) {
        throw new Error(data.error || 'Fehler beim Übermitteln der Stimme');
      }

      setIsSubmitted(true);
    } catch (err) {
      setError(err instanceof Error ? err.message : 'Ein Fehler ist aufgetreten');
    } finally {
      setIsLoading(false);
    }
  };

  if (isSubmitted) {
    return (
      <div className="container mx-auto px-4 py-8">
        <div className="ssvc-main-content text-center">
          <div className="mb-6">
            <div className="w-16 h-16 bg-[#e6f0fa] flex items-center justify-center mx-auto mb-4">
              <svg xmlns="http://www.w3.org/2000/svg" className="h-8 w-8 text-[#0057a6]" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
              </svg>
            </div>
            <h2 className="text-2xl font-bold text-[#0057a6] mb-2">Vielen Dank!</h2>
            <p className="text-gray-600">
              Deine Stimme wurde erfolgreich übermittelt.
            </p>
          </div>

          <Link
            href="/"
            className="ssvc-button inline-block"
          >
            Zurück zur Startseite
          </Link>
        </div>
      </div>
    );
  }

  return (
    <div className="container mx-auto px-4 py-8">
      <div className="mb-8">
        <h1 className="text-2xl font-bold text-[#0057a6] mb-4">ABSTIMMUNG</h1>

        <div className="ssvc-main-content">
          <form onSubmit={handleSubmit} className="space-y-6">
            <div>
              <div className="text-xl font-bold text-[#0057a6] mb-4">
                <EditableText id="vote-question" />
              </div>

              <div className="space-y-3">
                {voteOptions.map((option) => (
                  <label
                    key={option.id}
                    className="flex items-center p-3 border border-gray-200 cursor-pointer hover:bg-[#e6f0fa] transition-colors"
                  >
                    <input
                      type="radio"
                      name="vote"
                      value={option.id}
                      checked={selectedOption === option.id}
                      onChange={() => setSelectedOption(option.id)}
                      className="h-5 w-5 text-[#0057a6] border-gray-300"
                    />
                    <span className="ml-3 text-gray-800">{option.label}</span>
                  </label>
                ))}
              </div>
            </div>

            <div className="p-4 bg-[#f0f7ff] border border-[#cce0ff] rounded-lg">
              <label htmlFor="comment" className="flex items-center text-base font-medium text-[#0057a6] mb-2">
                <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5 mr-2" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M7 8h10M7 12h4m1 8l-4-4H5a2 2 0 01-2-2V6a2 2 0 012-2h14a2 2 0 012 2v8a2 2 0 01-2 2h-3l-4 4z" />
                </svg>
                Kommentare oder Vorschläge (Optional)
              </label>
              <div>
                <textarea
                  id="comment"
                  name="comment"
                  rows={4}
                  value={comment}
                  onChange={(e) => setComment(e.target.value)}
                  placeholder="Dein Kommentar..."
                  className="w-full px-4 py-2 border-2 border-gray-300 rounded-md bg-[#e6f0fa] focus:outline-none focus:border-[#0057a6] focus:ring-2 focus:ring-[#0057a6]/20 transition-all duration-200 shadow-sm"
                />
              </div>
              <p className="mt-1 text-sm text-gray-500">
                Bitte kurz fassen und auf konkretes Feedback beschränken.
              </p>
            </div>

            {error && (
              <div className="text-red-500 text-sm">{error}</div>
            )}

            <button
              type="submit"
              disabled={isLoading}
              className="ssvc-button w-full disabled:opacity-50"
            >
              {isLoading ? 'Wird übermittelt...' : 'Stimme abgeben'}
            </button>
          </form>
        </div>
      </div>
    </div>
  );
}
